balloon library

Classes

Balloon
BalloonClipper
A clipper that creates balloon-shaped clipping paths.
BalloonGlassClipper
Glass effect clipper that uses the same path logic as BalloonPainter.
BalloonNoSizeLayoutDelegate
BalloonPainter
BalloonShadow
BalloonTapDelegator
BalloonTapDelegator resolves the issue where tap events are not handled when displaying a Balloon using PositionedBalloon.
CustomBalloonShadow
Custom shadow.
FocusablePositionedBalloon
PositionedBalloon with focus.
MaterialBalloonShadow
it provide material elevation shadow
PositionedBalloon
PositionedBalloon is a decorator widget that provide the Balloon widget similar to Flutter's built-in Tooltip, allowing it to describe child widgets.
ShadowRenderer

Enums

BalloonNipPosition
BalloonNipPosition is an enum that represents the position of the balloon's nip.

Functions

calcNipHeight(double nipSize) double
createBalloonPath({required Size size, required BorderRadius borderRadius, required BalloonNipPosition nipPosition, required double nipSize, required double nipMargin, required double nipRadius}) Path
Shared balloon path creation logic used by both BalloonPainter and BalloonGlassClipper.
getRealNipHeight(double nipSize, double nipRadius) double