BalloonGlassClipper class
Glass effect clipper that uses the same path logic as BalloonPainter.
This clipper creates the exact same balloon shape including the nip for use with BackdropFilter to apply glass effect consistently.
- Inheritance
-
- Object
- Listenable
- CustomClipper<
Path> - BalloonGlassClipper
Constructors
- BalloonGlassClipper({required BalloonNipPosition nipPosition, required double nipSize, required double nipMargin, required double nipRadius, required BorderRadius borderRadius})
Properties
- borderRadius → BorderRadius
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nipMargin → double
-
final
- nipPosition → BalloonNipPosition
-
final
- nipRadius → double
-
final
- nipSize → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be notified when it is time to reclip.
inherited
-
getApproximateClipRect(
Size size) → Rect -
Returns an approximation of the clip returned by getClip, as
an axis-aligned Rect. This is used by the semantics layer to
determine whether widgets should be excluded.
inherited
-
getClip(
Size size) → Path -
Returns a description of the clip given that the render object being
clipped is of the given size.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies when it is time to reclip.
inherited
-
shouldReclip(
covariant BalloonGlassClipper oldClipper) → bool -
Called whenever a new instance of the custom clipper delegate class is
provided to the clip object, or any time that a new clip object is created
with a new instance of the custom clipper delegate class (which amounts to
the same thing, because the latter is implemented in terms of the former).
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited